#
# spec file for package xmlgraphics-fop
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2000-2008, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bname fop
Name:           xmlgraphics-fop
Version:        2.10
Release:        2.2
Summary:        Formatter for Printing XSLT Processed XML Files
License:        Apache-2.0
Group:          Productivity/Publishing/XML
URL:            https://xmlgraphics.apache.org/fop/
Source0:        https://archive.apache.org/dist/xmlgraphics/fop/source/fop-%{version}-src.tar.gz
Source1:        https://download.sourceforge.net/project/offo/offo-hyphenation/2.2/offo-hyphenation.zip
#FIX-OPENSUSE: add xmlgraphics-commons to classpath
Source2:        %{name}.script
Source3:        %{name}-fontmetrics.script
Source4:        %{name}-fontlist.script
# Manpage(s)
Source10:       %{name}.xml
Source11:       %{name}-fontmetrics.xml
Source12:       %{name}-fontlist.xml
Patch1:         xmlgraphics-fop-cli.patch
Patch2:         hyphenation-more-stack.patch
Patch3:         fix-javadoc-java8.patch
Patch4:         encoding.patch
# PATCH-FEATURE-OPENSUSE reproducible-build-manifest.patch -- boo#1110024
Patch5:         reproducible-build-manifest.patch
Patch6:         fop-2.10-QDox-2.0.patch
Patch7:         reproducible.patch
Patch8:         java8-compatibility.patch
BuildRequires:  ant >= 1.9.15
BuildRequires:  apache-pdfbox >= 2.0.23
BuildRequires:  bouncycastle
BuildRequires:  bouncycastle-pkix
BuildRequires:  bouncycastle-util
BuildRequires:  commons-io >= 2.4
BuildRequires:  commons-logging
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  jakarta-servlet
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  libxslt
BuildRequires:  qdox >= 2.0
BuildRequires:  unzip
BuildRequires:  xml-commons-apis
BuildRequires:  xmlgraphics-batik >= 1.18
BuildRequires:  xmlgraphics-commons >= 2.10
#!BuildIgnore:  saxon
Requires:       java >= 1.8
Requires:       xml-commons-apis
Provides:       %{bname} = %{version}-%{release}
Obsoletes:      %{bname} < %{version}-%{release}
Provides:       fo-formatter = %{version}-%{release}
BuildArch:      noarch

%description
FOP (Formatting Objects Processor) is driven by XSL formatting objects
(XSL-FO). It is a Java application that reads a formatting object (FO)
tree and renders the resulting pages to one of the following output
formats: PDF (primary output target), PCL, PS, SVG, XML (area tree
representation), Print, AWT, MIF, and TXT.

%prep
%setup -q -n %{bname}-%{version} -a1
ln -t fop/hyph offo-hyphenation/hyph/*.xml
find -name "*.jar" | xargs -t rm
%patch -P 1 -p1 -b .cli
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
%patch -P 8 -p1
%endif

# Replace keyword "VERSION" in XML files with the real one:
for x in %{SOURCE10} %{SOURCE11} %{SOURCE12}; do
 sed -i "s=@VERSION@=%{version}=" $x
done

# When building with ant, the fop.jar is an all-in jar,
# so adapt the dependencies accordingly

# Remove dependencies on fop modules included in the jar
%pom_remove_dep :fop-events fop
%pom_remove_dep :fop-util fop
%pom_remove_dep :fop-core fop

# Add dependencies of fop modules included in the jar
%pom_add_dep com.thoughtworks.qdox:qdox:2 fop
%pom_add_dep commons-io:commons-io:1.3.1 fop
%pom_add_dep commons-logging:commons-logging:1.0.4 fop
%pom_add_dep javax.servlet:servlet-api:2.2 fop
%pom_add_dep org.apache.pdfbox:fontbox:2.0 fop
%pom_add_dep org.apache.xmlgraphics:batik-anim:1.14 fop
%pom_add_dep org.apache.xmlgraphics:batik-awt-util:1.14 fop
%pom_add_dep org.apache.xmlgraphics:batik-bridge:1.14 fop
%pom_add_dep org.apache.xmlgraphics:batik-extension:1.14 fop
%pom_add_dep org.apache.xmlgraphics:batik-gvt:1.14 fop
%pom_add_dep org.apache.xmlgraphics:batik-transcoder:1.14 fop
%pom_add_dep org.apache.xmlgraphics:xmlgraphics-commons:2.6 fop

%build
build-jar-repository -s fop/lib \
        bcpkix \
        bcprov \
        bcutil \
        commons-io \
        commons-logging \
        fontbox \
        jakarta-servlet/jakarta.servlet-api \
        batik-all \
        xml-commons-apis \
        xml-commons-apis-ext \
        xmlgraphics-commons \
        qdox

ant \
    -f fop/build.xml \
    -Ddev=true \
    package

# Build the manpage(s) and HTML
DB=%{_datadir}/xml/docbook/stylesheet/nwalsh/current
for m in %{SOURCE10} %{SOURCE11} %{SOURCE12}; do
 xsltproc $DB/manpages/docbook.xsl $m
# Only filename for HTML is needed, remove anything before /
 xml=${m##*/}
 xsltproc --output ${xml%%.xml}.html $DB/html/docbook.xsl $m
done

%install
# jars
mkdir -p %{buildroot}%{_javadir}
install -m 644 fop/build/%{bname}.jar %{buildroot}%{_javadir}/%{name}.jar
install -m 644 fop/build/%{bname}-hyph.jar %{buildroot}%{_javadir}/%{name}-hyph.jar
install -m 644 fop/build/%{bname}-sandbox.jar %{buildroot}%{_javadir}/%{name}-sandbox.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} fop/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

# script
mkdir -p %{buildroot}%{_bindir}
cp -p %{SOURCE2}  %{buildroot}%{_bindir}/%{name}
cp -p %{SOURCE3}  %{buildroot}%{_bindir}/%{name}-fontmetrics
cp -p %{SOURCE4}  %{buildroot}%{_bindir}/%{name}-fontlist
# compat symlink
ln -s %{name}             %{buildroot}%{_bindir}/%{bname}
ln -s %{name}-fontmetrics %{buildroot}%{_bindir}/%{bname}-fontmetrics
ln -s %{name}-fontlist    %{buildroot}%{_bindir}/%{bname}-fontlist

# data
install -D -m 644 fop/conf/fop.xconf %{buildroot}%{_sysconfdir}/fop.xconf

# Manpages
mkdir -p %{buildroot}%{_mandir}/man1
for m in *.1; do
  gzip $m
done
cp -vi *.1.gz %{buildroot}%{_mandir}/man1

# Remove prefix xmlgraphics to make also the linked manpage version available
pushd %{buildroot}%{_mandir}/man1
for m in *.1.gz; do
  ln -s $m ${m#*-}
done
popd

%files -f .mfiles
%{_javadir}/%{name}-hyph.jar
%{_javadir}/%{name}-sandbox.jar
%license LICENSE
%doc NOTICE README fop/known-issues.xml
%doc *.html
%attr(0755,root,root) %{_bindir}/%{name}
%{_bindir}/%{bname}
%attr(0755,root,root) %{_bindir}/%{name}-fontmetrics
%{_bindir}/%{bname}-fontmetrics
%attr(0755,root,root) %{_bindir}/%{name}-fontlist
%{_bindir}/%{bname}-fontlist
%{_mandir}/man1/*
%config(noreplace) %{_sysconfdir}/fop.xconf

%changelog
* Wed Mar  5 2025 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * reproducible.patch
    + more use of SOURCE_DATE_EPOCH instead of current time to make
    xmlgraphics-fop generate reproducible documents
* Sat Oct 12 2024 Fridrich Strba <fstrba@suse.com>
- version 2.10
  * fixes XXE vulnerability bsc#1231428, CVE-2024-28168
  * Changes of 2.10
    + FOP-2764: footnote-body ignores rl-tb writing mode
    + FOP-3135: SVG tspan content is displayed out of place
    + FOP-3144: Add new schema to handle pdf/a and pdfa/ua
    + FOP-3146: Correct fop version at runtime
    + FOP-3148: NoSuchElementException when using font with no
    family name
    + FOP-3150: Resolve classpath for binary distribution
    + FOP-3158: Switch to spotbugs
    + FOP-3159: Set an automatic module name
    + FOP-3160: Rename packages to avoid conflicts with modules
    + FOP-3161: Resize table only for multicolumn page
    + FOP-3162: Missing jars in servlet
    + FOP-3163: Optimise performance of PNG with alpha using raw
    loader
    + FOP-3164: basic-link not navigating to corresponding footnote
    + FOP-3166: Add option to sign PDF
    + FOP-3168: Add secure processing for XSL input
    + FOP-3174: Allow sections which need security permissions to
    be run when AllPermission denied in caller code
    + FOP-3176: Remove unused PDFStructElem
    + FOP-3177: Remove space generated by fo:wrapper
    + FOP-3178: Reset content length for table changing ipd
    + FOP-3182: Add alt text to PDF signature
    + FOP-3184: Allow change of resource level for SVG in AFP
    + FOP-3185: Exclude shape not in clipping path for AFP
    + FOP-3186: Only support 1 column for redo of layout without
    page pos only
    + FOP-3188: Switch to Jakarta servlet API
    + FOP-3190: NPE when list item is split alongside an ipd change
    + FOP-3191: Add mandatory MODCA triplet to AFP
    + FOP-3192: Redo layout for multipage columns
    + FOP-3194: Add image mask option for AFP
    + FOP-3195: Skip written block ipds inside float
    + FOP-3198: Allow curly braces for src url
    + FOP-3204: Missing content for last page with change ipd
    + FOP-3207: Add warning when different pdf languages are used
    + FOP-3208: Only restart line manager when there is a linebreak
    for blocklayout
  * Changes of 2.9
    + FOP-1722: Values in PDF Number Trees must be indirect
    references
    + FOP-2903: Do not delete files on syntax errors using command
    line
    + FOP-2920: Surrogate pair edge-case causes Exception
    + FOP-2985: Reset character spacing
    + FOP-3042: SVG text containing certain glyphs isn't rendered
    + FOP-3088: Remove duplicate classes from maven classpath
    + FOP-3090: Allow use of page position only on redo of layout
    + FOP-3098: Failure to render multi-block itemBody alongside
    float
    + FOP-3107: Update to PDFBox 2.0.27
    + FOP-3110: NPE if link destination is missing with
    accessibility
    + FOP-3111: Make property cache thread safe
    + FOP-3114: Font size was rounded to 0 for AFP TTF
    + FOP-3115: Cannot process a SVG using mvn jars
    + FOP-3116: Remove serializer jar
    + FOP-3117: Allow creating a PDF 2.0 document
    + FOP-3118: Text missing after page break inside table inline
    + FOP-3120: IllegalArgumentException for list in a table
    + FOP-3121: Table width may be too wide when layout width
    changes
    + FOP-3125: NPE when using broken link and PDF 1.5
    + FOP-3127: Allow XMP at PDF page level
    + FOP-3129: Symbol font was not being mapped to unicode
    + FOP-3130: Correct font differences table for Chrome
    + FOP-3132: Link against Java 8 API
    + FOP-3139: Add support for
    font-selection-strategy=character-by-character
    + FOP-3140: Merge form fields in external PDFs
    + XGC-133: Fix test for Java 11
- Modified patches:
  * java8-compatibility.patch
    + approach problem differently and use release in ant javac task
  * xmlgraphics-fop-cli.patch
  * fop-2.5-QDox-2.0.patch -> fop-2.10-QDox-2.0.patch
    + rediff
- Added patches:
  * encoding.patch
    + specify encoding utf-8 to fix build with some versions of JDK
- Adapt the scripts to the fact that javapackages-tools do not
  require the JAVA_HOME to be set any more
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Adapt the scripts to the new javapackages-tools version
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jan 26 2023 Fridrich Strba <fstrba@suse.com>
- version 2.8
  * Changes:
    + FOP-2839: Links to pdf files with no scheme should open in pdf
    viewer
    + FOP-2860: Add light weight line breaking option
    + FOP-2861: Allow resource loading from jar
    + FOP-2865: Stroke-opacity is not honored on svg:text while
    conveting svg to pdf
    + FOP-2897: Skip OOM during font OS scanning
    + FOP-2910: Remove cidset for PDF/A-2
    + FOP-2969: Reorder glyphs with no width
    + FOP-2977: Array index out of bounds with glyph position
    adjustments and surrogate pairs
    + FOP-3015: Set text color for simulate-style
    + FOP-3023: Simulated bold error in Adobe Reader
    + FOP-3048: Resolve links across IF files
    + FOP-3049: Align AFP SVG text in the middle
    + FOP-3051: Upgrade to Commons IO 2.11
    + FOP-3053: Remove Xerces
    + FOP-3055: Use a event for a draw image error
    + FOP-3057: Allow fallback to non svg glyphs
    + FOP-3061: AFP invoke-medium-map missing when using
    page-group=false
    + FOP-3062: AssertionError with SFArabic.ttf
    + FOP-3067: README file still refers to bugzilla
    + FOP-3068: NPE when reading a invalid TTC file
    + FOP-3070: Batik is setting load-external-dtd to false so this
    example doesnt work
    + FOP-3071: Write mediummap before pagegroup
    + FOP-3072: Empty link url gives NPE
    + FOP-3074: Reorder glyphs based on gpa value
    + FOP-3077: Use all rulesets for glyph substitution
    + FOP-3078: Fix position of macron glyph
    + FOP-3080: Allow removing empty table elements from structure
    tree
    + FOP-3081: Fix change ipd for linefeed-treatment=preserve
    + FOP-3082: NPE when using a link in a span with accessibility
    + FOP-3085: Remove Xalan
    + FOP-3091: Add transparency color support
    + FOP-3092: PDF/UA NPE when using external pdf
    + FOP-3093: Stop reading ttf if we hit last offset
    + FOP-3094: Allow bookmarks before declarations
    + FOP-3101: Don't break with hangul syllables
    + FOP-3102: Move composite glyphs to the end
    + FOP-3103: NPE when using a footnote on redo of layout
    + FOP-3105: Infinite loop when using page break with changing
    ipd
    + XGC-130: Allow subproperties in XMP
    + XGC-132: Fallback to raw png if ImageIO cannot read image
- Removed patch:
  * update-2.7.patch
* Fri Jan 28 2022 Quang Tran <quang.tran@suse.com>
- version 2.7
  * Changes:
    + FOP-2928: PDFDocumentGraphics2D does not clear content on
    nextPage()
    + FOP-2943: NPE when inline character is a white space
    + FOP-2973: Cannot use custom schemes starting with "data" in
    resource resolver
    + FOP-2997: Double byte glyphs not working in SVG font
    + FOP-2999: Rollback after checking next page
    + FOP-3000: Absolute positioning wrong with AFP TTF
    + FOP-3002: Optimise memory usage for data uri
    + FOP-3006: XMP Metadata in created PDF/A-2 documents is not
    valid
    + FOP-3008: Table with linefeed-treatment may give
    ClassCastException
    + FOP-3014: ConcurrentModificationException for table cell
    + FOP-3016: Reorder thai marks for zero width
    + FOP-3017: Add option to disable positioning per char
    + FOP-3018: Allow to disable AFP page group
    + FOP-3019: Merge useragent encryption params with fop.xconf
    + FOP-3021: Improve validation of border property
    + FOP-3024: Make sure even number of bytes are output per trn
    for AFP TTF
    + FOP-3025: Keep table size on changing ipd which has graphics
    + FOP-3026: Fix NPE with empty table header
    + FOP-3027: Sections of text sometimes lost with span=all
    multiple columns
    + FOP-3028: Set values in fopFactoryBuilder setConfiguration
    + FOP-3030: AFP page overlay was written twice
    + FOP-3031: Add MCF before MDR in AFP
    + FOP-3032: Allow to embed native PDF in AFP
    + FOP-3033: Update PDFBox to 2.0.21
    + FOP-3034: Update PDFBox to 2.0.24
    + FOP-3038: Allow sections which need security permissions to
    be run when AllPermission denied in caller code
    + FOP-3039: AFP include-page-overlay missing X and Y via IF
    + FOP-3046: Don't use page position only on redo of layout
    + XGC-128: Remove image transparency for PS
  * Allow to embed native PDF in AFP
- Added patch:
  * update-2.7.patch
* Sun Jan 24 2021 Fridrich Strba <fstrba@suse.com>
- version 2.6
  * Changes:
    + FOP-1648: Fix pdf internal named destinations
    + FOP-2536: Allow overpaint of PDF border
    + FOP-2889: Make JAI optional
    + FOP-2919: NPE printing
    + FOP-2935: Make servlet a compile only dependency
    + FOP-2939: Upgrade ant to 1.9.15
    + FOP-2941: SVG container with stroke=black has an unexpected
    border
    + FOP-2945: Don't use change ipd on columns where it won't fit
    + FOP-2950: Display font error at top level exception
    + FOP-2957: Don't change ipd on lastpage if column count changes
    + FOP-2958: Error when using both AFP truetype and base14 font
    + FOP-2960: Soft-Hyphen on Hyphenated words
    + FOP-2975: Put composite glyphs to separate font
    + FOP-2978: Include composite glyphs in otf subset
    + FOP-2979: Update PDFBox to 2.0.19
    + FOP-2980: Reduce filesize for AFP Graphics2D
    + FOP-2981: Convert CFF CID to Type1
    + FOP-2989: Missing text in AFP output when using high
    resolution
    + FOP-2990: Changing ipd doesn't handle table narrowing
    + FOP-2992: List broken too early without change ipd
    + FOP-2994: Support OTF/TTF SVG fonts
    + XGC-123: Decode image at page load rather than document load
  * Support OTF/TTF SVG fonts
  * Allow overpaint of PDF border
* Sat Jan 23 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Thu Jun  4 2020 Fridrich Strba <fstrba@suse.com>
- version 2.5
  * Changes:
    + FOP-1606: Incorrect border when using number-columns-spanned
    in RTF
    + FOP-2704: Don't fail on coverage set class table not
    supported
    + FOP-2889: Make JAI optional
    + FOP-2892: Font substitutions not working
    + FOP-2894: Fit table contents onto current page
    + FOP-2895: Add missing classes to allinone jar
    + FOP-2898: Only use zero glue for change ipd
    + FOP-2901: NoSuchElementException on empty table footer
    + FOP-2902: Ignore TTF reserved index range
    + FOP-2907: Missing bounding box on repeated image for PDF/UA
    + FOP-2908: Repeated image in header not shown in structure tree
    + FOP-2909: Hide empty blocks from structure tree
    + FOP-2911: Add endpage event for FO to IF
    + FOP-2923: Allow to suppress fo:leader within empty paragaphs
    from structure tree
    + FOP-2924: Images not scaled or rotated in PCL
    + FOP-2925: Change in IPD on empty block NPE
    + FOP-2926: Add artifact type to PDF header/footer
    + FOP-2934: Absolute element should not be removed
  * Allow to hide empty blocks from structure tre
  * Does not need avalon-framework to build or run
  * Adapt the command-line scripts by removing avalon-framework
    from classpath
  * Build against fontbox from apache-pdfbox >= 2
  * Use the included pom file instead of downloading the same
    file from maven central
- Removed patch:
  * fop-2.1-batik-xmlconstants.patch
    + Included directly in this version. Requires batik >= 1.11
- Modified patches:
  * fop-2.1-QDox-2.0.patch -> fop-2.5-QDox-2.0.patch
  * fix-javadoc-java8.patch
  * hyphenation-more-stack.patch
  * java8-compatibility.patch
  * reproducible-build-manifest.patch
  * xmlgraphics-fop-cli.patch
    + Port to fop 2.5
* Mon May 18 2020 Fridrich Strba <fstrba@suse.com>
- Do not install the OFFO hyphenation files to datadir, but package
  instead the xmlgraphics-fop-hyph.jar and
  xmlgraphics-fop-sandbox.jar that we build anyway. This fixes
  boo#1145693
- Clean up the build a bit
* Fri Apr  3 2020 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * fop-2.1-batik-xmlconstants.patch
    + apply when building with batik >= 1.11
    + batik 1.11 moved XMLConstants class from
    org.apache.batik.util to org.apache.batik.constants
* Wed Aug 14 2019 Frank H. Ellenberger <frank.h.ellenberger@gmail.com>
- Add fontbox to classpath: (rh#1413340)
* Mon Apr 15 2019 Fridrich Strba <fstrba@suse.com>
- Build against glassfish-servlet-api
* Mon Jan 21 2019 Fridrich Strba <fstrba@suse.com>
- Fix build with new avalon-framework and batik
- Install maven pom file
* Fri Jan  4 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * fop-2.1-QDox-2.0.patch
    + Build against QDox >= 2
* Thu Dec  6 2018 Fridrich Strba <fstrba@suse.com>
- Bring back the java-devel/java requirements to >= 1.8; we will
  fix the ByteBuffer/CharBuffer compatibilities as they arise.
- Modified patch:
  * java8-compatibility.patch
    + Fix fix ByteBuffer/CharBuffer incompatibilities with java8
    Cast all the java.nio.ByteBuffer and java.nio.CharBuffer
    instances to java.nio.Buffer before calling the clear(),
    flip(), limit(int), mark(), reset() and rewind() methods.
* Thu Nov 15 2018 thomas.schraitle@suse.com
- version 2.1
  Change requirement from java-devel-openjdk >= 1.8.0 to
  java-devel-openjdk >= 9 to avoid tracebacks because of compatibility
  issues with java.nio.Buffer, for example:
  java.lang.NoSuchMethodError:
  java.nio.CharBuffer.rewind()Ljava/nio/CharBuffer;
* Wed Nov  7 2018 Fridrich Strba <fstrba@suse.com>
- Do not depend on a particular xml-commons-apis provider.
* Mon Oct 29 2018 antoine.belvire@opensuse.org
- Add reproducible-build-manifest.patch: Remove custom "Build-Id"
  from manifests. It contains date and other information making the
  build unreproducible (boo#1110024).
* Tue Aug 28 2018 tchvatal@suse.com
- Fix building with ant >= 1.9.12
* Thu Apr  5 2018 fstrba@suse.com
- Added patch:
  * java8-compatibility.patch
    + Fix compatibility with java8 and lower when built with java9
    or higher
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Tue Sep 19 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target 1.6 and fix
  javadoc build
* Fri May 19 2017 vsistek@suse.com
- Add BuildRequires: javapackages-local (for maven conversions)
* Mon Mar  6 2017 sknorr@suse.com
- Make sure to apply new file list for Tumbleweed only
  (FATE#322405)
* Thu Mar  2 2017 fvogt@suse.com
- Add patch to fix build with stricter javadoc in version 8:
  * fix-javadoc-java8.patch (boo#1027467)
- Fix file list on SLE
* Tue Mar  8 2016 fvogt@suse.com
- Fix manpage for xmlgraphics-fop-fontmetrics
* Thu Mar  3 2016 fvogt@suse.com
- Update to fop 2.1
  - https://xmlgraphics.apache.org/fop/changes.html#version_2.1
- Remove upstreamed fop-commons-2.0.patch
    and xmlgraphics-fop-xconf.patch
- Add hyphenation-more-stack.patch to fix build with offo 2.2
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Mon Dec  8 2014 tchvatal@suse.com
- Spec-cleanify
- Do not ever run tests, we lack quite packages to do so anyway
- Drop fop-1.1-src.tar.gz.asc xmlgraphics-fop.keyring as upstream
  does not provide those anymore
- Apply patch to build with new xmlgraphics-commons:
  * fop-commons-2.0.patch
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-trax
* Thu Sep 12 2013 tchvatal@suse.com
- Drop javadoc package so we build this package
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Sep  6 2013 mvyskocil@suse.com
- use new add_maven_depmap
- add missing commons packages to BuildRequires
- add gpg verification
* Thu Apr 25 2013 mvyskocil@suse.com
- fix a typo in a xmlgraphics-fop.script (bnc#817145)
* Mon Jan 28 2013 mvyskocil@suse.com
- (build) require xml-commons-apis, the org.w3c.svg are used inside fop
  part of a fix for bnc#800694
* Thu Jan 10 2013 mvyskocil@suse.com
- drop excalibur usage from all classpaths, use avalon-framework instead
* Mon Dec 17 2012 mvyskocil@suse.com
- drop excalibur-avalon from dependencies, fop now uses avalon-framework
* Sun Dec  9 2012 slavb18@gmail.com
- patched fop.xconf
  * added <auto-detect/> to pdf renderer section, so now possible to use system fonts like font-family="DejaVuSansMono"
- fix the spec file to install a (default) fop.xconf file in /etc
- patched scripts to use /etc/fop.xconf
* Tue Nov 20 2012 mvyskocil@suse.com
- add fo-formatter to provides upon a request of doc team
* Wed Nov 14 2012 slavb18@gmail.com
- fixed "Class not found" errors in fop scripts
* Thu Oct 25 2012 mvyskocil@suse.com
- add commons-logging and commons-io to Requires and fop script
- removed uneeded xalan-j2, xmlcommons and xerces from dependencies
* Wed Oct 24 2012 mvyskocil@suse.com
- update to 1.1
  * many bug fixes and a number of improvements
  * support for Complex Scripts (e.g., Arabic, Hebrew, Indic, and Southeast
  * Asian scripts)
  * http://xmlgraphics.apache.org/fop/1.1/releaseNotes_1.1.html
  * This release implements a substantial subset of the W3C
  * XSL-FO 1.1 Recommendation. For a detailed overview of FOP's compliance with
  * this recommendation, see Compliance.
  * http://xmlgraphics.apache.org/fop/compliance.html
- obsoleted xmlgraphics-fop-asf51789.patch
- obsoleted xmlgraphics-fop-build.patch
* Fri Sep  9 2011 giecrilj@stegny.2a.pl
- restored gzipped archive to avoid HTTP 404
- disabled tests (they take ages to build and they fail anyway, so do we really need them)?
- added standard hyphenation from OFFO
- told ant to use UTF-8
- fix for asf#51789
* Fri May 13 2011 toms@suse.de
- Recompressed gzip archive to bz2 to avoid warning
- Fixed non-conffile-in-etc warning for %%{_mavendepmapfragdir}
- Added new xmlgraphics-fontmetrics and xmlgraphics-fontlist scripts
  to help for better FOP configuration
- Added manpage and HTML for all scripts (xmlgraphics-fop,
  xmlgraphics-fop-fontmetrics, and xmlgraphics-fop-fontlist)
- Created links without prefix xmlgraphics-fop for
  xmlgraphics-fop-fontmetrics and xmlgraphics-fop-fontlist
- Created links for all manpages without prefix xmlgraphics-fop
* Wed May 11 2011 toms@suse.de
- Added two new scripts for creating font metrics and font lists
* Mon May  2 2011 toms@suse.de
- Fixed xmlgraphic-fop script:
  * Added excalibur/avalon-framework-impl in BASE_JAR variable to
    avoid exception in thread "main" java.lang.NoClassDefFoundError:
    org/apache/avalon/framework/configuration/DefaultConfigurationBuilder
    Caused by: java.lang.ClassNotFoundException:
    org.apache.avalon.framework.configuration.DefaultConfigurationBuilder
  * Replaced xmlgraphics-batik/util in BASE_JAR variable to
    avoid ClassNotFoundException: org.apache.batik.bridge.UserAgent
* Tue Nov 16 2010 mvyskocil@suse.cz
- correct fop Provides: Obsolete:
* Wed Nov  3 2010 mvyskocil@suse.cz
- fix bnc#650138 - fop update wanted
  * fix memory leak in property cache
  * change FONode.addCharacters() parameter to closer match the signature of the standard SAX characters() event
  * new event handling framework
  * support for font substitution
  * support for addressing all glyphs available in a Type 1 font,
    not just the ones in the font's primary encoding.
  * limited support for pages of different inline-progression-dimensions within a page-sequence.
  * minimal support for integer keep values on the various keep properties on block-level FOs.
  * new AFPGraphics2D implementation which provides the ability to use Batik to
    drive the production of AFP Graphics (GOCA) output from SVG.
  * new Resource group leveling, external streaming, and de-duplication of images and
  graphics using IncludeObject and ResourceGroup.
  * new Native image embedding support (e.g. JPEG, GIF, TIFF) using ObjectContainer
    and a MOD:CA Registry implementation.
- merge with xmlgraphics-fop-0.95-6.jpp5.src.rpm
* Thu Feb 26 2009 mvyskocil@suse.cz
- fixed bnc#467866 - fop fails if JAVACMD_OPTS is set
* Wed Aug  6 2008 skh@suse.de
- update to version 0.95, list of changes at:
  http://xmlgraphics.apache.org/fop/0.95/changes_0.95.html
- fop requires java 1.4 now
- use unversioned Requires: jre
* Fri Jun 27 2008 coolo@suse.de
- avoid build cycle between fop and saxon
* Wed Jan 30 2008 skh@suse.de
- update to version 0.94, major changes:
  * Add support for font auto-detection (JM) Thanks to Adrian Cumiskey
  * Add support for the border-collapsing model in tables (VH, JM)
  * Add support for named destinations in PDF (JB)
  * Add support for UAX#14 type line breaking (MM)
  full list of changes at:
  http://xmlgraphics.apache.org/fop/0.94/changes_0.94.html
* Tue Jul 10 2007 skh@suse.de
- update to version 0.93
- build with gcj
* Sun May  6 2007 ro@suse.de
- added unzip to buildrequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep 17 2004 skh@suse.de
- do no longer use setJava
* Wed Apr 28 2004 ke@suse.de
- Provide wrapper scripts for fop.sh and xalan.sh to make it find the
  java environment; reported by Thomas Schraitle; fix provided by Petr
  Mladek [#39581].
* Mon Oct 27 2003 ke@suse.de
- New package: version 0.20.5.
